<?php

/*
Plugin Name: ePermissions
Plugin URI: http://www.mubde3.net/blog/archives/epermissions-plugin/
Description: ePermissions plugin allows you to manage your members (who have Editor role) and you can make for them capabilities that you choose only for them.
Version: 1.2
Author: Ahmed Alkatheeri
Author URI: http://www.mubde3.net/
*/

/*  Copyright 2010  Ahmed Alkatheeri  (email : mobde3net@gmail.com)
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

define(ePermission_Path_Name,'epermissions');

// Variables of sql results in ePermissions class
// $gtr_value: First value gotten, $gtr_value2: Second value gotten, $gtr_value3: Third value gotten
// $table_name: The name of current table in SQL query
// $get_table_results_values: Get result in one array before flowing in each value

class ePermissions {
    
    var $plugin_dir_lang; // Current languages in ePermissions plugin
    var $epermissions_feat_caps; // Current permission features (capabilities) in ePermissions plugin
    
    // Construct of class
    function __construct() {
        $this->epermissions_feat_caps = array(
            1 => 'publish_posts', 2 => 'edit_posts', 3 => 'edit_others_posts', 4 => 'edit_private_posts',
            5 => 'edit_published_posts', 6 => 'delete_posts', 7 => 'delete_others_posts', 8 => 'delete_private_posts',
            9 => 'delete_published_posts', 10 => 'publish_pages', 11 => 'edit_pages', 12 => 'edit_others_pages',
            13 => 'edit_private_pages', 14 => 'edit_published_pages', 15 => 'delete_pages', 16 => 'delete_others_pages',
            17 => 'delete_private_pages', 18 => 'delete_published_pages', 19 => 'manage_categories',
            20 => 'manage_links', 21 => 'moderate_comments', 22 => 'read', 23 => 'read_private_posts',
            24 => 'read_private_pages',25 => 'upload_files', 26 => 'unfiltered_html'
        );
        $this->plugin_dir_lang = '/wp-content/plugins/'.ePermission_Path_Name.'/lang/';
        define(Numbers_Of_Features, 26);
        
        // Activating ePermissions plugin in wordpress
        add_action('activate_'.ePermission_Path_Name.'/ePermissions.php', array(&$this, 'epermissions_install_plugin'));
        
        // Deactivating ePermissions plugin in wordpress
        add_action('deactivate_'.ePermission_Path_Name.'/ePermissions.php', array(&$this, 'epermissions_uninstall_plugin'));

        // CSS and Javascript codes in header of admin area
        add_action('admin_head', array(&$this, 'epermissions_layout'));

        // Main menu for ePermissions
        add_action('admin_menu', array(&$this, 'epermissions_admin_menu'));
        add_action('admin_menu', array(&$this, 'epermissions_unset_menu'));
        
        // About init functions
        add_action('init', array(&$this, 'epermissions_ini'));
        
        // Appearing permission's message in the top of admin pages
        add_action('admin_notices',array(&$this, 'epermissions_appear_per_msg'));
        
        // Updating users' profile for add current permissions to them
        add_action('profile_update', array(&$this, 'epermissions_update_user_page'));
        
        // Adding the layout of select current permissions in edit user profile page
        add_action('edit_user_profile', array(&$this, 'epermissions_select_user_page'));
        
    }
    
    // For installing ePermissions plugin
    function epermissions_install_plugin() {
    
            global $wpdb;
            $table_name = $wpdb->prefix.'users_permissions';
            
            if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") == False) {
               $sql = "CREATE TABLE $table_name (
                    permission_id INT NOT NULL AUTO_INCREMENT ,
                    permission_creator_id INT NOT NULL ,
                    permission_name VARCHAR(180) NOT NULL ,
                    permission_status ENUM('Opened', 'Closed') NOT NULL ,
                    permission_message TEXT NOT NULL ,
                    permission_features TEXT NOT NULL ,
                    permission_date timestamp NOT NULL default CURRENT_TIMESTAMP,
                    PRIMARY KEY (permission_id)
                ) DEFAULT CHARSET=utf8";
                
                $wpdb->query($sql);
             
            }
            
            $alter_table = $wpdb->query("ALTER TABLE ".$wpdb->prefix."users ADD permission_id INT NOT NULL DEFAULT '0'");
            if($alter_table) { return true;}
            
            
    }
    
    // For uninstalling ePermissions plugin
    function epermissions_uninstall_plugin() {
    
        global $wpdb;
        $table_name = $wpdb->prefix.'users_permissions';
        
        
        $set_default_per = $wpdb->query("UPDATE ".$wpdb->prefix."users SET permission_id = '0'");
        if($set_default_per) {
            $this->epermissions_make_cap(0);
            if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") == TRUE) {
                $wpdb->query("DROP TABLE IF EXISTS $table_name");
                $wpdb->query("ALTER TABLE ".$wpdb->prefix."users DROP COLUMN permission_id");
            }
        }
        
        
    }
    
    // Convert date from english to arabic in permission table
    function epermissions_convert_date($sql_date,$format, $convert = 0) {
        
        if(WPLANG == 'ar') { $convert = 1; }
        $date=strtotime($sql_date);
        $final_date=date($format, $date);
        if($convert == 1) {
            $en_date_chars = array('January','February','March','April','May','June','July','August','September','October','November', 'December', 'am', 'pm');
            $ar_date_chars = array('يناير','فبراير','مارس','أبريل','مايو','يونيو','يوليو','أغسطس','سبتمبر','أكتوبر','نوفمبر', 'ديسمبر', 'صباحاً', 'مساءاً');
            $final_date_convert = str_replace($en_date_chars ,$ar_date_chars, $final_date);
            return $final_date_convert;
        } else {
            return $final_date;
        }
    }
    
    // protecting html input
    function epermissions_input_sec($value) {
        
        if(get_magic_quotes_gpc()) {
            $new_value = stripslashes($value);
        } else {
            $new_value = $value;
        }
        
        $string = mysql_real_escape_string($new_value);
        return $string;
    }
    
    // Getting features from database by separate them
    function epermissions_get_features ($per, $value,$page) {
        if($page == 'edit') {
            $var = explode(',', $per);
            for($i = 0;$i <= Numbers_Of_Features; $i++) { 
                if($var[$i] == $value) { return true; }
            }
        } else if ($page == 'add') {
            if(((!$_POST['permission_name']) || (!$_POST['permission_status'])) && $_POST['per-add-submit']) {
                $per_features_num = count($_POST[$per]);
                for($i=0; $i < $per_features_num; $i++) {
                    if($_POST[$per][$i] == $value) {
                        return true;
                    }
                }
            }
        }
    }
    
    // Check if user's role is editor
    function epermissions_check_per_cap($status='Opened',$id=NULL) {
        global $wpdb, $current_user;
        $table_name = $wpdb->prefix.'users_permissions';
    
        if($id==NULL) {
            get_currentuserinfo();
            $user_id = $current_user->ID;
        } else {
            $user_id = $id;
        }
        
        $gtr_value = $wpdb->get_var("SELECT permission_id FROM ".$wpdb->prefix."users WHERE ID='$user_id'");
        $gtr_value2 = $wpdb->get_row("SELECT * FROM $table_name WHERE permission_id='$gtr_value'");
        $gtr_value3 = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."usermeta WHERE meta_key = 'wp_user_level' AND user_id = '$user_id' ");
        if($gtr_value2->permission_status == $status && $gtr_value3->meta_value >= 5 && !($gtr_value3->meta_value > 7)) {
            return True;
        } else {
            return False;
        }
    }
    
    // Create css code for plugin
    function epermissions_layout () { ?>
        <style type="text/css" media="screen">
        .p-table-control {
            margin: 0 auto;
            width: 97%;
        }
        .p-table-control thead th, .p-table-control tfoot th, .p-table-control tbody td { text-align: center; }
        .per-inputs {
            margin: 4px 0;
            padding: 3px 2px 5px;
            width: 650px;
        }
        .per-multi-field {
            margin: 4px;
        }
        .form-table { width: 98%; }
        #permission_msg {
            margin: 30px 10px 0;
            padding: 5px;
            width: 94%;
            border: 1px solid #f3c800;
            background-color: #fff1af;
            color: #4c493d;
            -moz-border-radius: 5px;
            -webkit-border-radius: 5px;
        }
        .permission-features-box {
			background-color: #fff;
			border: 1px solid #D2D2D2;
			margin-bottom: 15px;
			border-radius: 5px;
			width: 650px;
			-moz-border-radius: 5px;
			-webkit-border-radius: 5px;
			-moz-box-shadow: 0 0 4px #e7e7e7;
		}
		.permission-features-headline{
			padding: 5px 0;
			background: #d9d9d9 url(../wp-content/plugins/<?php echo ePermission_Path_Name; ?>/img/box-light.png) 0 -3px repeat-x;
		}
		.permission-features-headline h3 {
			margin: 0 15px;
			font: bold 16px "Times New Roman", Times, serif;
			color: #2f2f2f;
		}
		.permission-features-list {
			padding-left:12px;
			list-style: none;
			overflow: hidden;
		}
		.permission-features-list li {
			margin: 4px;
			padding: 1px 0 0;
			display: inline-block;
		}
		input[type="checkbox"], input[type="radio"] {
			vertical-align: middle;
		}
        .permission-select {
            <?php if(WPLANG == 'ar') { ?>
                margin: 0 0 10px 7px;
                float: left;
            <?php } else { ?>
                margin: 0 7px 10px 0;
                float: right;
            <?php } ?>
        	padding: 5px 10px;
            background: #d9d9d9 url(../wp-content/plugins/<?php echo ePermission_Path_Name; ?>/img/box-light.png) 0 -3px repeat-x;
        	border: 1px solid #c3c3c3;
            -moz-border-radius: 5px;
            -moz-box-shadow: 0 0 4px #E7E7E7;
            display: inline-block;
        	cursor: pointer;
        }
        .main-feature {
            color: #004377;
            font-weight:  bold;
        }
        </style>
        <script type="text/javascript">
            jQuery(function($){
                
                $('.permission-select').hover(function(){
                    $(this).animate({
                        'opacity':0.8,
                        'duration':1000
                    });
                },function(){
                    $(this).animate({
                        'opacity':1,
                        'duration':1000
                    });
                });
                var curFeat = new Array();
                $('.per-multi-field[checked~=checked]').each(function(i){
                        if($(this).attr('type') == 'checkbox') {
                            curFeat[i] = $(this).attr('value');
                        }
                });
                
                $('#per-return-all').click(function(){
                    $('.per-multi-field').each(function(){
                        if($(this).attr('type') == 'checkbox') {
                            $(this).removeAttr('checked');
                            
                            for(i=0; i < 26; i++) {
                                if(curFeat[i] == $(this).val()) {
                                    $(this).attr('checked','checked');
                                }
                            }
                            
                        }
                    });
                });
                
                $('#per-select-all').click(function(){
                    $('.per-multi-field').each(function(){
                        if($(this).attr('type') == 'checkbox') {
                            $(this).attr('checked','checked');
                        }
                    });
                });
                $('#per-unselect-all').click(function(){
                    $('.per-multi-field').each(function(){
                        if($(this).attr('type') == 'checkbox') {
                            $(this).removeAttr('checked');
                        }
                    });
                });
            });
        </script>
        <?php }
    
    // Add initial code for admin pages specially for current languages
    function epermissions_ini() {
        load_plugin_textdomain('editors_permissions',$this->plugin_dir_lang);
    }
    
    // Appear special message for user if he has one
    function epermissions_appear_per_msg () {
        global $wpdb, $current_user;
        $table_name = $wpdb->prefix.'users_permissions';
        get_currentuserinfo();
        $current_user_id = $current_user->ID;
        
        $gtr_value = $wpdb->get_var("SELECT permission_id FROM ".$wpdb->prefix."users WHERE ID='$current_user_id'");
        $gtr_value2 = $wpdb->get_row("SELECT * FROM $table_name WHERE permission_id='$gtr_value'");
            if($this->epermissions_check_per_cap('Opened')) {
                if(!empty($gtr_value2->permission_message)) {?>
                <div id="permission_msg"><?php echo $gtr_value2->permission_message; ?></div>
    
                <?php }
            }
    }
    
    // Update user's profile with new permission
    function epermissions_update_user_page() {
        global $wpdb;
        $table_name = $wpdb->prefix.'users';
        $user_id = $_POST['user_id'];
        $permission_id = $_POST['permission'];
        
        if($_POST['submit']) {
            if($_POST['role'] == 'editor') {
                $update_per_value = "UPDATE $table_name SET permission_id=$permission_id WHERE ID=$user_id";
                $wpdb->query($update_per_value);
                $this->epermissions_make_cap($permission_id);
            } else {
                $update_per_value = "UPDATE $table_name SET permission_id=0 WHERE ID=$user_id";
                $wpdb->query($update_per_value);
                $this->epermissions_make_cap(0);
            }
            
        } else {
            return false;
        }
    }
    
    // Add permission field to user's profile
    function epermissions_select_user_page() {
        
        global $wpdb;
        $table_name = $wpdb->prefix.'users_permissions';
        $user_id = $_GET['user_id'];
        $get_table_results_values = $wpdb->get_results("SELECT permission_id, permission_name FROM $table_name WHERE permission_status = 'Opened'");
        $gtr_value = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."users WHERE ID=$user_id"); ?>
         <h3><?php _e('Permission for user','editors_permissions'); ?></h3>
                <table class="form-table">
                	<tr>
                		<th><label for="permission"><?php _e('Select Permission','editors_permissions'); ?></label></th>
                		<td>
                			<select id="permission" name="permission">
                    			<option value="0" <?php if($gtr_value->permission_id == 0) { echo 'selected="selected"'; } ?>><?php _e('Unselected','editors_permissions'); ?></option>
                                <?php foreach($get_table_results_values AS $gtr_value2) {
                                    if($gtr_value->permission_id == $gtr_value2->permission_id) { $selected='selected="selected"'; } else { $selected=null; }
                                    echo "<option value=\"".$gtr_value2->permission_id."\" $selected>".$gtr_value2->permission_name."</option>";
                                } ?>
                			</select>
                			<span class="description"><?php _e('This is an optional field, you can make it as unselected if you want.', 'editors_permissions'); ?></span>
                		</td>
                	</tr>
                </table>
    <?php }
    
    // The page of adding new permission
    function epermissions_add_permission_page() {
        global $current_user;
        ?>  <div id="wrap"> <?php 
        if($_GET['action'] == 'add' && $_POST['per-add-submit']) {
            
            $permission_message = $this->epermissions_input_sec($_POST['permission_message']);
            $permission_creator_id = $this->epermissions_input_sec($_POST['permission_creator_id']);
            if(empty($_POST['permission_name'])){
                $per_name_error_style = 'style="border: 1px solid red;"';
                echo '<p><strong style="color:red;">'.__('You must write permission name!','editors_permissions').'</strong></p>';
            } else {
                $permission_name = $this->epermissions_input_sec($_POST['permission_name']);
            }
            if(empty($_POST['permission_status'])) {
                $per_status_error_style = 'style="border: 1px solid red;"';
                echo '<p><strong style="color:red;">'.__('You must write permission status!','editors_permissions').'</strong></p>';
            } else {
                $permission_status = $this->epermissions_input_sec($_POST['permission_status']);
            }
            if($_POST['permission_features']) {
                $permission_features = implode(',',$_POST['permission_features']);
                $permission_features = $this->epermissions_input_sec($permission_features);
            } else if (empty($_POST['permission_features'])) {
                $permission_features = 0;
            }
            
            
            if($permission_name && $permission_status && $permission_creator_id) {
                global $wpdb;
                $table_name = $wpdb->prefix.'users_permissions';
                
                $insert_per_values = "INSERT INTO $table_name (permission_name, permission_status, permission_features, permission_message, permission_creator_id, permission_date) VALUES ('$permission_name','$permission_status','$permission_features','$permission_message','$permission_creator_id',NOW())";
                if($wpdb->query($insert_per_values)) {
                     $message = __('Added new permission, back to <a href="admin.php?page=editors-per-home-page">first page of permissions</a>.','editors_permissions');
                }
            }
            
        }
    ?>
            <h2><?php _e('Add New Permission','editors_permissions'); ?></h2>
            <p><?php _e('You can add your permission in this page.','editors_permissions'); ?></p>
            
            <form method="post" action="admin.php?page=editors-per-add-permission-page&action=add">
            <?php if($message) { echo '<div class="updated fade" id="message"><p>'.$message.'</p></div>'; } ?>
            <table class="form-table">
            	<tbody>
            		<tr valign="top" <?php echo $per_name_error_style ?>>
            			<th><label for="permission_name"><?php _e('Permission Name','editors_permissions'); ?></label></th>
            			<td><input class="per-inputs" name="permission_name" type="text" value="<?php if(isset($_POST['permission_name']) && (!$message)) { echo $_POST['permission_name']; } ?>" /></td>
            		</tr>
                    
                    <tr valign="top" <?php echo $per_status_error_style ?>>
            			<th><label for="status"><label><?php _e('Status','editors_permissions'); ?></label></label></th>
            			<td>
                            <input class="per-multi-field" name="permission_status" type="radio" value="Opened" <?php if(isset($_POST['permission_status']) && $_POST['permission_status'] == 'Opened' && (!$message)) { echo 'checked="checked"';  } ?> /> <?php _e('Opened','editors_permissions'); ?>
                            <input class="per-multi-field" name="permission_status" type="radio" value="Closed"  <?php if(isset($_POST['permission_status']) && $_POST['permission_status'] == 'Closed' && (!$message)) { echo 'checked="checked"';  } ?> /> <?php _e('Closed','editors_permissions'); ?>
                        </td>
            		</tr>
                    
                    <tr valign="top">
            			<th><label for="permission_feature"><label><?php _e('Permission Features','editors_permissions'); ?></label></label></th>
            			<td>                                                                             
                            <!-- Short Select and Unselect -->
                            <div style="overflow: hidden; width: 658px;">
                                <span class="permission-select" id="per-select-all"><?php _e('Selecting all features','editors_permissions'); ?></span>
                                <span class="permission-select" id="per-unselect-all"><?php _e('Unselecting all features','editors_permissions'); ?></span>
                            </div>
                            <!-- /Short Select and Unselect -->
                            
                            <!-- Features List -->
							<div class="permission-features-box">
                            	
                                <div class="permission-features-headline">
                                    <h3><?php _e('Posts Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="2" <?php if($this->epermissions_get_features('permission_features', 2, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="1" <?php if($this->epermissions_get_features('permission_features', 1, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Publish posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="3" <?php if($this->epermissions_get_features('permission_features', 3, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit others posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="4" <?php if($this->epermissions_get_features('permission_features', 4, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="5" <?php if($this->epermissions_get_features('permission_features', 5, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit published posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="6" <?php if($this->epermissions_get_features('permission_features', 6, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="7" <?php if($this->epermissions_get_features('permission_features', 7, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete others posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="8" <?php if($this->epermissions_get_features('permission_features', 8, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="9" <?php if($this->epermissions_get_features('permission_features', 9, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete published posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="21" <?php if($this->epermissions_get_features('permission_features', 21, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Moderate comments (You need to activate \'Edit others posts\' and \'Edit published posts\')','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Pages Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="11" <?php if($this->epermissions_get_features('permission_features', 11, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="10" <?php if($this->epermissions_get_features('permission_features', 10, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Publish pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="12" <?php if($this->epermissions_get_features('permission_features', 12, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit others pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="13" <?php if($this->epermissions_get_features('permission_features', 13, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit private pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="14" <?php if($this->epermissions_get_features('permission_features', 14, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit published pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="15" <?php if($this->epermissions_get_features('permission_features', 15, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="16" <?php if($this->epermissions_get_features('permission_features', 16, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete others pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="17" <?php if($this->epermissions_get_features('permission_features', 17, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Delete private pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="18" <?php if($this->epermissions_get_features('permission_features', 18, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Edit published pages','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Management Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="19" <?php if($this->epermissions_get_features('permission_features', 19, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Manage categories','editors_permissions'); ?></li>
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="20" <?php if($this->epermissions_get_features('permission_features', 20, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Manage links','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Reading Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="22" <?php if($this->epermissions_get_features('permission_features', 22, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Read (read Dashboard page)','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="23" <?php if($this->epermissions_get_features('permission_features', 23, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Read private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="24" <?php if($this->epermissions_get_features('permission_features', 24, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Read private pages','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Media Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="25" <?php if($this->epermissions_get_features('permission_features', 25, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Upload files','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="26" <?php if($this->epermissions_get_features('permission_features', 26, 'add')) { echo 'checked="checked"';} ?> /> <?php _e('Unfiltered html','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            <!-- /Features List/ -->
                            <ul style="width: 650px;">
                                <li class="main-feature"><?php _e('The colored feature is main key of each features category, and it can shows/hides admin menus of member who has this permission.','editors_permissions'); ?></li>
                            </ul>
                        </td>
            		</tr>
                    
                    <tr valign="top">
            			<th><label for="permission_message"><label><?php _e('Permission Message','editors_permissions'); ?></label></label></th>
            			<td><textarea name="permission_message" class="large-text code"><?php if(isset($_POST['permission_message']) && (!$message)) { echo $_POST['permission_message']; } ?></textarea></td>
            		</tr>
                    
            	</tbody>
            </table>
            <?php get_currentuserinfo();?>
            <p class="submit"> <input name="permission_creator_id" type="hidden" value="<?php echo $current_user->ID; ?>" /> <input class="button-primary" name="per-add-submit" type="submit" value="<?php _e('Add','editors_permissions'); ?>" /></p>
            </form>
        </div>
    <?php 
    
    }
    
    // The home page of ePermissions
    function epermissions_home_page() {
    ?>
        <div id="wrap">
        
        <?php if($_GET['action'] == 'edit') {
        if($_POST['per-edit-submit']) {
            $permission_id = $this->epermissions_input_sec($_POST['permission_id']);
            $permission_status = $this->epermissions_input_sec($_POST['permission_status']);
            $permission_message = $this->epermissions_input_sec($_POST['permission_message']);
            $unselect_msg = '<p><strong style="color:red;">'.__('This permission didn\'t update, check these field again (Permission Name, Permission Status).','editors_permissions').'</strong></p>';
            if(!empty($_POST['permission_name'])){
                $permission_name = $this->epermissions_input_sec($_POST['permission_name']);
            }
            if(!empty($_POST['permission_features'])) {
                $permission_features = implode(',',$_POST['permission_features']);
            } else if (empty($_POST['permission_features'])) {
                $permission_features = 0;
            }
            if( empty($_POST['permission_name'])) {
                echo $unselect_msg;
            }
    
            if($permission_name && $permission_status) {
                global $wpdb;
                $table_name = $wpdb->prefix.'users_permissions';
                
                $update_per_values = "UPDATE $table_name SET permission_name = '$permission_name' , permission_status = '$permission_status' , permission_features = '$permission_features' , permission_message = '$permission_message' WHERE permission_id = '$permission_id'";
                
                if($wpdb->query($update_per_values)) {
                     $message = __('Updated permission, back to <a href="admin.php?page=editors-per-home-page">first page of permissions</a>.','editors_permissions');
                     $this->epermissions_make_cap($permission_id);
                     
                }
             }
             
        }
         global $wpdb;
         $table_name = $wpdb->prefix.'users_permissions';   
         $permission_id = $_GET['id'];
         $gtr_value = $wpdb->get_row("SELECT * FROM $table_name WHERE permission_id = '$permission_id'");
    
        ?>
            <h2><?php _e('Edit Permission','editors_permissions'); ?></h2>
            <p><?php _e('You can edit your permission in this page.','editors_permissions'); ?></a></p>
            
            <form method="post" action="admin.php?page=editors-per-home-page&action=edit&id=<?php echo $_GET['id'] ?>">
            <?php if($message) { echo '<div class="updated fade" id="message"><p>'.$message.'</p></div>'; } ?>
            <table class="form-table">
            	<tbody>
            		<tr valign="top">
            			<th><label for="permission_name"><?php _e('Permission Name','editors_permissions'); ?></label></th>
            			<td><input class="per-inputs" name="permission_name" type="text" value="<?php echo $gtr_value->permission_name; ?>" /></td>
            		</tr>
                    
                    <tr valign="top">
            			<th><label for="status"><label><?php _e('Status','editors_permissions'); ?></label></label></th>
            			<td>
                            <input class="per-multi-fields" name="permission_status" type="radio" value="Opened" <?php if($gtr_value->permission_status == 'Opened') { echo 'checked="checked"';} ?> /> <?php _e('Opened','editors_permissions'); ?>
                            <input class="per-multi-field" name="permission_status" type="radio" value="Closed" <?php if($gtr_value->permission_status == 'Closed') { echo 'checked="checked"';} ?> /> <?php _e('Closed','editors_permissions'); ?>
                        </td>
            		</tr>
                    
                    <tr valign="top">
            			<th><label for="permission_feature"><label><?php _e('Permission Features','editors_permissions'); ?></label></label></th>
            			<td>
                            <!-- Short Select and Unselect -->
                            <div style="overflow: hidden; width: 658px;">
                                <span class="permission-select" id="per-select-all"><?php _e('Selecting all features','editors_permissions'); ?></span>
                                <span class="permission-select" id="per-unselect-all"><?php _e('Unselecting all features','editors_permissions'); ?></span>
                                <span class="permission-select" id="per-return-all"><?php _e('Returning last features','editors_permissions'); ?></span>
                            </div>
                            <!-- /Short Select and Unselect -->
                            
                            <!-- Features List -->
							<div class="permission-features-box">
                            	
                                <div class="permission-features-headline">
                                    <h3><?php _e('Posts Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="2" <?php if($this->epermissions_get_features($gtr_value->permission_features, 2, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="1" <?php if($this->epermissions_get_features($gtr_value->permission_features, 1, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Publish posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="3" <?php if($this->epermissions_get_features($gtr_value->permission_features, 3, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit others posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="4" <?php if($this->epermissions_get_features($gtr_value->permission_features, 4, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="5" <?php if($this->epermissions_get_features($gtr_value->permission_features, 5, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit published posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="6" <?php if($this->epermissions_get_features($gtr_value->permission_features, 6, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="7" <?php if($this->epermissions_get_features($gtr_value->permission_features, 7, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete others posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="8" <?php if($this->epermissions_get_features($gtr_value->permission_features, 8, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="9" <?php if($this->epermissions_get_features($gtr_value->permission_features, 9, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete published posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="21" <?php if($this->epermissions_get_features($gtr_value->permission_features, 21, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Moderate comments (You need to activate \'Edit others posts\' and \'Edit published posts\')','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Pages Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="11" <?php if($this->epermissions_get_features($gtr_value->permission_features, 11, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="10" <?php if($this->epermissions_get_features($gtr_value->permission_features, 10, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Publish pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="12" <?php if($this->epermissions_get_features($gtr_value->permission_features, 12, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit others pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="13" <?php if($this->epermissions_get_features($gtr_value->permission_features, 13, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit private pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="14" <?php if($this->epermissions_get_features($gtr_value->permission_features, 14, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Edit published pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="15" <?php if($this->epermissions_get_features($gtr_value->permission_features, 15, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="16" <?php if($this->epermissions_get_features($gtr_value->permission_features, 16, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete others pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="17" <?php if($this->epermissions_get_features($gtr_value->permission_features, 17, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete private pages','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="18" <?php if($this->epermissions_get_features($gtr_value->permission_features, 18, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Delete published pages','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Management Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="19" <?php if($this->epermissions_get_features($gtr_value->permission_features, 19, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Manage categories','editors_permissions'); ?></li>
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="20" <?php if($this->epermissions_get_features($gtr_value->permission_features, 20, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Manage links','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Reading Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="22" <?php if($this->epermissions_get_features($gtr_value->permission_features, 22, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Read (read Dashboard page)','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="23" <?php if($this->epermissions_get_features($gtr_value->permission_features, 23, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Read private posts','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="24" <?php if($this->epermissions_get_features($gtr_value->permission_features, 24, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Read private pages','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            
                            <div class="permission-features-box">
                            	<div class="permission-features-headline">
                            		<h3><?php _e('Media Features','editors_permissions'); ?></h3>
                                </div>
                                
                                <ul class="permission-features-list">
                                    <li class="main-feature"><input class="per-multi-field" name="permission_features[]" type="checkbox" value="25" <?php if($this->epermissions_get_features($gtr_value->permission_features, 25, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Upload files','editors_permissions'); ?></li>
                                    <li><input class="per-multi-field" name="permission_features[]" type="checkbox" value="26" <?php if($this->epermissions_get_features($gtr_value->permission_features, 26, 'edit')) { echo 'checked="checked"';} ?> /> <?php _e('Unfiltered html','editors_permissions'); ?></li>
                                </ul>
                            </div>
                            <!-- /Features List/ -->
                            <ul style="width: 650px;">
                                <li class="main-feature"><?php _e('The colored feature is main key of each features category, and it can shows/hides admin menus of member who has this permission.','editors_permissions'); ?></li>
                            </ul>
                            
                        </td>
            		</tr>
                    
                    <tr valign="top">
            			<th><label for="permission_message"><label><?php _e('Permission Message','editors_permissions'); ?></label></label></th>
            			<td><textarea name="permission_message" class="large-text code"><?php echo $gtr_value->permission_message; ?></textarea></td>
            		</tr>
                    
            	</tbody>
            </table>
            <p class="submit"> <input name="permission_id" type="hidden" value="<?php echo $_GET['id']; ?>" /> <input class="button-primary" name="per-edit-submit" type="submit" value="<?php _e('Update', 'editors_permissions'); ?>" /></p>
            </form>
            
        <?php } elseif($_GET['action'] == 'delete') {
            global $wpdb;
            $table_name = $wpdb->prefix.'users_permissions';
            $permission_id=$_GET['id'];
    
            $gtr_value = $wpdb->get_row("SELECT * FROM $table_name WHERE permission_id = '$permission_id'");
            
    
        ?>
            <h2><?php printf(__('Do you want delete (%s) permission?','editors_permissions'),$gtr_value->permission_name); ?></h2>
            <form method="post" action="admin.php?page=editors-per-home-page">
                <p class="submit"><input name="permission_id" type="hidden" value="<?php echo $_GET['id']; ?>" /> <input class="button-primary" name="per-delete-submit" type="submit" value="<?php _e('Delete Permission','editors_permissions'); ?>" /></p>
            </form>
        <?
        } else {
            if($_POST['per-delete-submit']) {
                global $wpdb;
                $table_name = $wpdb->prefix.'users_permissions';
                $permission_id = $this->epermissions_input_sec($_POST['permission_id']);
                
                $delete_per_result = "DELETE FROM $table_name WHERE permission_id = '$permission_id'";
                if($wpdb->query($delete_per_result)) {
                    $wpdb->query("UPDATE ".$wpdb->prefix."users SET permission_id = '0' WHERE permission_id = '$permission_id'");
                    $message = __('Deleted old permission.','editors_permissions');
                    $this->epermissions_make_cap(0);
                }
                
                
            }
            ?>
            <h2><?php _e('Editors Permissions Page','editors_permissions'); ?></h2>
            
            <p><?php _e('This is home page of ePermissions plugin.','editors_permissions'); ?></p>
            <?php if($message) { echo '<div class="updated fade" id="message"><p>'.$message.'</p></div>'; } ?>
            
            
            <?php
            
            global $wpdb;
            $table_name = $wpdb->prefix.'users_permissions';
            $get_table_results_vars = $wpdb->get_var("SELECT * FROM $table_name");
            
            if($get_table_results_vars == TRUE) {
            ?>
            
            <p><?php _e('You can <a href="admin.php?page=editors-per-add-permission-page">add new permission</a> to your members. Also, see this table if you want edit any permissions.', 'editors_permissions'); ?></p>
            
        <!-- Table -->
        <table class="p-table-control widefat fixed" cellspacing="1">
        
        <!-- Table header -->
        
        <thead>
            <tr>
                <th width="3%">#</th>
                <th width="42%"><?php _e('Permission','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Members','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Status','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Created by','editors_permissions'); ?></th>
                <th width="15%"><?php _e('Date','editors_permissions'); ?></th>
                <th width="15%"><?php _e('Options','editors_permissions'); ?></th>
            </tr>
        </thead>
        
        <!-- Table body -->
        
        <tbody>
            <?php
            $get_table_results_values = $wpdb->get_results("SELECT * FROM $table_name");
            
            foreach ($get_table_results_values as $gtr_value) {
                $get_member_id_per_create = $wpdb->get_var("SELECT display_name FROM ".$wpdb->prefix."users WHERE ID = '".$gtr_value->permission_creator_id."'");
                $get_num_query = $wpdb->query("SELECT permission_id FROM ".$wpdb->prefix."users WHERE permission_id = '$gtr_value->permission_id'");
                $get_num_user_per = $wpdb->num_rows;
                echo '<tr>';
                echo '  <td>'.$gtr_value->permission_id.'</td>';
                echo '  <td>'.$gtr_value->permission_name.'</td>';
                echo '  <td> '.$get_num_user_per.' </td>';
                echo '  <td>'.__($gtr_value->permission_status,'editors_permissions').'</td>';
                echo '  <td>'.$get_member_id_per_create.'</td>';
                echo '  <td>'.$this->epermissions_convert_date($gtr_value->permission_date, 'j F Y').'</td>';
                echo '  <td><a href="'.get_bloginfo('url').'/wp-admin/admin.php?page=editors-per-home-page&action=edit&id='.$gtr_value->permission_id.'" title="Edit this permission">'.__('Edit','editors_permissions').'</a> | <a href="'.get_bloginfo('url').'/wp-admin/admin.php?page=editors-per-home-page&action=delete&id='.$gtr_value->permission_id.'" title="Delete this permission">'.__('Delete','editors_permissions').'</a></td>';
                echo '</tr>';
            }
            ?>
        </tbody>
        
        <tfoot>
            <tr>
                <th width="3%">#</th>
                <th width="42%"><?php _e('Permission','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Members','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Status','editors_permissions'); ?></th>
                <th width="10%"><?php _e('Created by','editors_permissions'); ?></th>
                <th width="15%"><?php _e('Date','editors_permissions'); ?></th>
                <th width="15%"><?php _e('Options','editors_permissions') ?></th>
            </tr>
        </tfoot>
        
        </table>
        <!-- /Table -->
            
            <?php 
            } else { ?>
                <p><?php _e('There are not any permissions to show, you can <a href="admin.php?page=editors-per-add-permission-page">add new permission</a> to your members.', 'editors_permissions'); ?></p>
             <? }
            
            }
            ?>
            
        </div>
    <?php 
    
    }
    
    // unset comments menu if user doesn't have moderate_comments capability
    function epermissions_unset_menu() {
        global $menu,$current_user;
        get_currentuserinfo();
        
        $valid_page = 'admin.php?page=esx3.edit.comment';
        $user = new WP_User($current_user->ID);
        
        if(!$user->has_cap('moderate_comments')) {
            unset($menu[25]);
            if(preg_match('/(.*?)\/wp-admin\/?(edit-comments.php|comment.php)(.*?)/',$_SERVER['REQUEST_URI']) == true) {
                wp_redirect(get_option('siteurl') . '/wp-admin/' . $valid_page);
            }
        }
        
        
        
    }
    
    // Add and remove capabilities from user (who must has Editor role)
    function epermissions_make_cap($permission_id) {
        global $wpdb,$menu;

        $table_name = $wpdb->prefix.'users_permissions';
        
        // Fetch editors' identifications for give capabilities to them
        $user_id=$wpdb->get_results("SELECT ID FROM ".$wpdb->prefix."users WHERE permission_id = '$permission_id'");
        
        foreach($user_id AS $usd) {

            $gtr_value = $wpdb->get_var("SELECT permission_id FROM ".$wpdb->prefix."users WHERE ID = '".$usd->ID."'");
            $gtr_value2 = $wpdb->get_row("SELECT permission_id, permission_features, permission_status FROM $table_name WHERE permission_id = '$gtr_value'");
            
            // Check if permission has one or more features
            $epermissions_features = explode(',',$gtr_value2->permission_features);
            $epermissions_features = is_array($epermissions_features)?$epermissions_features:array($gtr_value2->permission_features);
            
            $user = new WP_User($usd->ID);
            if($permission_id != 0) {
                
                if ($this->epermissions_check_per_cap('Opened',$user->id)) {
                    // Get the keys of current capabilities
                    foreach ($this->epermissions_feat_caps AS $e_feat_key => $e_feat_value) {
                        // Add capability to current user from permission features
                        if(in_array($e_feat_key,$epermissions_features)) {
                            if (!$user->has_cap($e_feat_value) && array_key_exists($e_feat_value, $user->allcaps) && !$user->allcaps[$e_feat_value]) {
                                 unset($user->caps[$e_feat_value]);
                                 update_usermeta($user->id, $user->cap_key, $user->caps);
                            }
                            if($e_feat_value == 'edit_others_posts') {
                                 $user->add_cap($e_feat_value);
                            }
                        }
                        
                        // Remove capability to current user from permission features (that unselected from administrator)
                        if(!in_array($e_feat_key,$epermissions_features)) {
                            if($user->has_cap($e_feat_value)) {
                               $user->add_cap($e_feat_value,false);    
                            }
                        }
                        
                        
                    }
                }
                if ($this->epermissions_check_per_cap('Closed',$user->id)) {
                    foreach ($this->epermissions_feat_caps AS $e_feat_key => $e_feat_value) {
                        
                        // Add default Editor capabilities to current user from permission features
                        if (!$user->has_cap($e_feat_value) && array_key_exists($e_feat_value, $user->allcaps) && !$user->allcaps[$e_feat_value]) {
                             unset($user->caps[$e_feat_value]);
                             update_usermeta($user->id, $user->cap_key, $user->caps);
                        }
                    }
                    $user->remove_cap('edit_others_posts');
                }
                
                
            
            } elseif ($permission_id == 0) {
                // Get the keys of current capabilities
                foreach ($this->epermissions_feat_caps AS $e_feat_key => $e_feat_value) {
                    
                    // Add default Editor capabilities to current user from permission features
                    if (!$user->has_cap($e_feat_value) && array_key_exists($e_feat_value, $user->allcaps) && !$user->allcaps[$e_feat_value]) {
                         unset($user->caps[$e_feat_value]);
                         update_usermeta($user->id, $user->cap_key, $user->caps);
                    }
                }
                $user->remove_cap('edit_others_posts');
            }
                    
        }
    }
    // Add ePermissions menu to admin menu of administrator
    function epermissions_admin_menu() {
        add_menu_page(__('Editors Permissions Page','editors_permissions'), 'ePermissions', 10, 'editors-per-home-page', array(&$this,'epermissions_home_page'), WP_PLUGIN_URL . '/'.ePermission_Path_Name.'/img/ePerIcon.png');
        add_submenu_page('editors-per-home-page', __('Editors Permissions','editors_permissions'), __('Permissions','editors_permissions'), 10, 'editors-per-home-page', array(&$this,'epermissions_home_page'));
        add_submenu_page('editors-per-home-page', __('Add new permission','editors_permissions'), __('Add new permission','editors_permissions'), 10, 'editors-per-add-permission-page', array(&$this,'epermissions_add_permission_page'));
    }
    
}

// Run ePermissions plugin by the main class (ePermissions class)
if (class_exists('ePermissions')) { $epermission = new ePermissions; }

?>